from typing import Dict, Optional, Union, List, Any

from django import template
from django.urls import reverse

register = template.Library()


@register.inclusion_tag('academy_theme/templatetags/breadcrumb.html')
def breadcrumb(title: str, *args, **kwargs) -> Dict[str, Union[str, Optional[str]]]:
    """
    Returns bootstrap compatible breadrumb.
    """
    url_name: str = 'NO NAME'
    if args:
        url_name = args[0]
        if len(args) == 1:
            url_args: List[Any] = []
        else:
            url_args = list(args[1:])
    return {
        'title': title,
        'url': reverse(url_name, *url_args, **kwargs) if url_name else None
    }



from typing import Dict, Any
from django.conf import settings
from django.http.request import HttpRequest
from django.templatetags.static import static


def theme(request: HttpRequest) -> Dict[str, Any]:
    """
    Inject our theme variables into our templates.
    """
    theme_settings: Dict[str, Any] = getattr(settings, 'ACADEMY_THEME_SETTINGS', {})
    return {
        # Header
        'APPLE_TOUCH_ICON': static(theme_settings.get('APPLE_TOUCH_ICON', 'academy_theme/images/apple-touch-icon.png')),
        'FAVICON_32': static(theme_settings.get('FAVICON_32', 'academy_theme/images/favicon-32x32.png')),
        'FAVICON_16': static(theme_settings.get('FAVICON_16', 'academy_theme/images/favicon-16x16.png')),
        'FAVICON': static(theme_settings.get('FAVICON', 'academy_theme/images/favicon.ico')),
        'SITE_WEBMANIFEST': static(theme_settings.get('ORGANIZATION_NAME', 'academy_theme/images/site.webmanifest')),

        # Footer
        'ORGANIZATION_LINK': theme_settings.get('ORGANIZATION_LINK', 'https://google.com'),
        'ORGANIZATION_NAME': theme_settings.get('ORGANIZATION_NAME', 'Organization Name'),
        'ORGANIZATION_ADDRESS': theme_settings.get('ORGANIZATION_ADDRESS', 'Organization Address'),
        'COPYRIGHT_ORGANIZATION': theme_settings.get('COPYRIGHT_ORGANIZATION', 'Copyright Organization'),
        'FOOTER_LINKS': theme_settings.get('FOOTER_LINKS', []),

        # Settings
        'BODY_STYLE': theme_settings.get('BODY_STYLE', 'centered')
    }



from setuptools import setup, find_packages

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name="django-theme-academy",
    version="0.3.1",
    packages=find_packages(),
    include_package_data=True,
    package_data={'academy_theme': ["py.typed"]},
    install_requires=[
        "django-wildewidgets >= 0.13.49"
    ],
    author="Caltech IMSS ADS",
    author_email="imss-ads-staff@caltech.edu",
    url="https://github.com/caltechads/django-theme-academy",
    description="A Tabler-based, fixed left sidebar django theme.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords=['django'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Topic :: Software Development :: Testing',
    ],
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from typing import List, Tuple

from django.templatetags.static import static

from wildewidgets import (
    CardWidget,
    VerticalDarkMenu,
    Block
)
from wildewidgets import __version__ as wildewidgets_version

from academy_theme import __version__ as theme_version


#------------------------------------------------------
# Menus
#------------------------------------------------------

class AcademyThemeMainMenu(VerticalDarkMenu):
    brand_image: str = static("academy_theme/images/logo.png")
    brand_image_width: str = "100%"
    brand_text: str = "Academy Theme"
    items: List[Tuple[str, str]] = [
        ('Home', 'core:home'),
        ('Wildewidgets', 'core:wildewidgets')
    ]


#------------------------------------------------------
# Widgets
#------------------------------------------------------

class DatagridItem(Block):
    block: str = 'datagrid-item'
    title: str = None
    content: str = None

    def __init__(self, **kwargs):
        self.title = kwargs.pop('title', None)
        self.content = kwargs.pop('content', None)
        super().__init__(**kwargs)
        self.add_block(Block(self.title, name='datagrid-title'))
        self.add_block(Block(self.content, name='datagrid-content'))


class Datagrid(Block):
    block: str = 'datagrid'

    def add_item(self, title: str, content: str, **kwargs) -> None:
        """
        Add a :py:class:`DatagridItem` to contents.

        Args:
            title: the label for the item
            content: the content of the item
        """
        self.add_block(DatagridItem(title=title, content=content, **kwargs))


#------------------------------------------------------
# Cards
#------------------------------------------------------

class AcademyInfoCardWidget(CardWidget):
    card_title: str = f'Version {theme_version}'

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        grid = Datagrid()
        grid.add_item('Wildewidgets Version', wildewidgets_version)
        grid.add_item('Tabler Version', '', css_id="tabler-version")
        grid.add_item('Bootstrap Icons Version', '', css_id="bootstrap-icons-version")
        grid.add_item('jQuery Version', '', css_id="jquery-version")
        self.set_widget(grid)
